@@ -515,4 +515,26 @@ sub decode_base64_urlsafe
 }
 
 1;
+__END__
+
+=head1 NAME
+
+OpenResty::Handler::Captcha - The captcha handler for OpenResty
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+This OpenResty handler class implements the Captcha API, i.e., the C</=/captcha/*> stuff.
+
+=head1 METHODS
+
+=head1 AUTHORS
+
+chaoslawful (王晓哲) C<< <chaoslawful at gmail dot com> >>,
+Agent Zhang (agentzh) C<< <agentzh@gmail.com >>
+
+=head1 SEE ALSO
+
+L<OpenResty::Handler::View>, L<OpenResty::Handler::Role>, L<OpenResty::Handler::Action>, L<OpenResty::Handler::Feed>, L<OpenResty::Handler::Version>, L<OpenResty::Handler::Model>, L<OpenResty::Handler::Login>, L<OpenResty>.
 
